zebra_printer library

Classes

BluetoothDevice
BluetoothManager
Class for managing Bluetooth operations
DiscoveredPrinter
Discovered Zebra Printer model
PrinterInfo
Printer information model
PrinterManager
Class for communicating with Zebra printers using Link-OS SDK
PrintProgress
Print progress information with comprehensive printer status
ZebraConfig
Configuration for Zebra Printer package
ZebraPrinterStatus
Comprehensive printer status from Zebra Link-OS SDK Contains all status information available from PrinterStatus class in SDK

Enums

BluetoothBondState
Enum for Bluetooth device bond states
BluetoothConnectionState
Enum for Bluetooth connection state
BluetoothDeviceType
Enum for Bluetooth device types
BluetoothScanState
Enum for Bluetooth scan state
CalibrationType
Calibration type for Zebra printers
DiscoveryType
Discovery type for Zebra printer discovery
PrinterLanguage
Enum for printer language
PrintState
Enum for print state

Exceptions / Errors

PrintLockedException
Exception thrown when a print operation is blocked because another print operation is already in progress on a different printer.