PrintState enum
Enum for print state
Values
- idle → const PrintState
-
Print job is idle
- connecting → const PrintState
-
Connecting to printer
- sending → const PrintState
-
Sending data to printer
- printing → const PrintState
-
Printer is actively printing
- verifying → const PrintState
-
Verifying print completion
- processing → const PrintState
-
Printer is processing data
- completed → const PrintState
-
Print completed successfully
- error → const PrintState
-
Print failed with error
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String? value) → PrintState - Creates PrintState from native string
Constants
-
values
→ const List<
PrintState> - A constant List of the values in this enum, in order of their declaration.